#
#  FILE NAME:
#      logger.py
#
#  AUTHOR(S):
#      Dariusz Walczak <dariusz.walczak@gmail.com>
#

# Standard imports:
import logging.config
import StringIO

# P3 imports:
from p3.conf.error import ConfModuleError

## Load config_file and format it to replace LOG_OUTPUT_FILE formatting directive with value of
#  output_file parameter. Note, that any '%' characters which aren't supposed to be interpreted as
#  formatting directives in this process (e.g. used in datefmt or format options) have to be
#  escaped (doubled).
def configure_logging_module( config_file, output_file ):
    cfg_template = open( config_file ).read()
    cfg_string = cfg_template % { 'LOG_OUTPUT_FILE': output_file }
    logging.config.fileConfig( StringIO.StringIO( cfg_string ) )

## High level, standarized logger configuration function purposed to retrieve all logger related
#  configuration data from provided settings object and properly initialize logging module with it.
#
#  Currently the function attempts to retrieve logger configuration and output file names and
#  passes it to the configure_logging_module function if successful.
def configure_logger( settings ):
    log_output_file = settings.get_setting( "LOG_OUTPUT_FILE" )

    if log_output_file is None:
        raise ConfModuleError( ConfModuleError.codes.unspecified_log_output_file,
                               "Specified settings module doesn't define 'LOG_OUTPUT_FILE'"
                               " setting." )

    log_config_file = settings.get_setting( "LOG_CONFIG_TEMPLATE_FILE" )

    if log_config_file is None:
        raise ConfModuleError( ConfModuleError.codes.unspecified_log_config_file,
                               "Specified settings module doesn't define"
                               "'LOG_CONFIG_TEMPLATE_FILE' setting." )

    configure_logging_module( log_config_file, log_output_file )
