#
#  FILE NAME:
#      var_converter.py
#
#  AUTHOR(S):
#      Dariusz Walczak <dariusz.walczak@gmail.com>
#

# Standard library imports:
import logging

# P3 imports:
from p3.logic.var.converter.conversion_result import ConversionResult


_LOG = logging.getLogger( "p3.logic" )


class VarConverter( object ):
    def __init__( self, deserialize_cb, serialize_cb=None, type_cb=None ):
        self._des_cb = deserialize_cb
        self._ser_cb = serialize_cb
        self._type_cb = type_cb


    def deserialize( self, value ):
        if not isinstance( value, basestring ):
            raise TypeError(
                "The value parameter must be of basestring type (got {0:s} instead)."
                "".format( type(value) ) )

        res = ConversionResult( value, self.__class__ )

        res.out_val = self._des_cb( res )

        assert res.out_val is None or self._type_cb is None or self._type_cb(res.out_val)

        return res


    def serialize( self, value ):
        if (self._type_cb is not None) and (not self._type_cb(value)):
            raise TypeError(
                "The value parameter is of unsupported type ({0:s})."
                "".format( type(value) ) )

        res = ConversionResult( value, self.__class__ )

        res.out_val = self._ser_cb( res )

        assert res.out_val is None or isinstance( res.out_val, basestring )

        return res
