#
#  FILE NAME:
#      test_case_2_6.py
#
#  AUTHOR(S):
#      Dariusz Walczak <dariusz.walczak@gmail.com>
#

# Standard library imports:
import logging
import unittest


## Provide some of specialized assertion methods added to the unittest.TestCase class in Python
#  2.7. Only the assertions currently used by p3 and dbut regression test suites are defined. Other
#  assertion methods may be added in future.
class TestCase( unittest.TestCase ):
    def _makeMsg( self, base, opt ):
        if opt is None:
            return "{0:s} ({1:s})".format( base, opt )
        else:
            return base


    def assertIs( self, first, second, msg=None ):
        if first is not second:
            exc_msg = self._makeMsg(
                "{0:s} is not {1:s}".format( repr(first), repr(second) ), msg )
            raise self.failureException( exc_msg )


    def assertIsNone( self, value, msg=None ):
        if value is not None:
            exc_msg = self._makeMsg( "{0:s} is not None".format( repr(value) ), msg )
            raise self.failureException( exc_msg )


    def assertIsNotNone( self, value, msg=None ):
        if value is None:
            exc_msg = self._makeMsg( "{0:s} is None".format( repr(value) ), msg )
            raise self.failureException( exc_msg )


    def assertTupleEqual( self, first, second, msg=None ):
        if not isinstance(first, tuple):
            raise self.failureException(
                self._makeMsg( "{0:s} is not tuple".format( repr(first) ), msg ) )

        if not isinstance(second, tuple):
            raise self.failureException(
                self._makeMsg( "{0:s} is not tuple".format( repr(second) ), msg ) )

        if len(first) <> len(second):
            raise self.failureException(
                self._makeMsg(
                    "first tuple length ({0:d}) differs from second tuple length ({1:d})"
                    "".format( len(first), len(second) ), msg ) )

        for i, f, s in zip(range(len(first)), first, second):
            if f <> s:
                raise self.failureException(
                    self._makeMsg(
                        "tuples differ at position {0:d} ({1:s} <> {2:s})"
                        "".format( i, repr(f), repr(s) ), msg ) )

