#
#  FILE NAME:
#      separate_database_case.py
#
#  AUTHOR(S):
#      Dariusz Walczak <dariusz.walczak@gmail.com>
#

# Standard library imports:
import logging
import unittest

# P3 imports:
from p3.db import DbConnection
from p3.db.manage import create_db, drop_db


_LOG = logging.getLogger( "p3.test" )


# Used when separate, clean database is expected by each of cases.
class SeparateDatabaseCase( unittest.TestCase ):
    def __init__( self, case_name ):
        super( SeparateDatabaseCase, self ).__init__( case_name )

        self._case_name = case_name
        self.mng_dbc = None
        self.tst_dbc = None


    def get_management_db_spec( self ):
        return self.MANAGEMENT_DB_SPEC


    def get_test_db_spec( self ):
        return self.TEST_DB_SPEC


    def setUp( self ):
        self.mng_dbc = DbConnection.create_from_dict( self.get_management_db_spec() )
        test_db_spec = self.get_test_db_spec()
        db_name = test_db_spec.get('name')
        create_db( self.mng_dbc, db_name, True )
        self.tst_dbc = DbConnection.create_from_dict( test_db_spec )


    def tearDown( self ):
        db_name = self.tst_dbc.db_name
        self.tst_dbc = None
        drop_db( self.mng_dbc, db_name )
        self.mng_dbc = None
        
